Write

Struct Write 

pub struct Write { /* private fields */ }
Draws mobjects in one after another, manim’s Write: each outline traces in, then its fill fades up while the outline fades back to its own style. See [write].