ReplacementTransform

Struct ReplacementTransform 

pub struct ReplacementTransform { /* private fields */ }
Morphs one mobject into another already in the scene, then swaps them, manim’s ReplacementTransform: target is hidden until the end, when it takes over and id is removed. See replacement_transform.